%global pypi_name jupyterlab

%bcond_with check

Name:           python-%{pypi_name}
Version:        4.3.4
Release:        %mkrel 2
Summary:        Environment for interactive and reproducible computing
License:        BSD-3-Clause
Group:          Development/Python
URL:            https://github.com/jupyterlab/jupyterlab
Source0:        %{pypi_source}
BuildArch:	noarch
BuildRequires:  jupyter-jupyterlab-filesystem
BuildRequires:  jupyter-jupyterlab-server
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  nodejs >= 10
BuildRequires:  npm >= 10
BuildRequires:  pyproject-rpm-macros

%description
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is the next-generation user interface for Project Jupyter
offering all the familiar building blocks of the classic Jupyter
Notebook (notebook, terminal, text editor, file browser, rich outputs,
etc.).

%package     -n python3-%{pypi_name}
Summary:        Environment for interactive and reproducible computing
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is the next-generation user interface for Project Jupyter
offering all the familiar building blocks of the classic Jupyter
Notebook (notebook, terminal, text editor, file browser, rich outputs,
etc.).

%package     -n jupyter-%{pypi_name}
Summary:        Environment for interactive and reproducible computing
Requires:       python3-jupyter-core
Requires:       jupyter-jupyterlab-filesystem
Requires:       jupyter-jupyterlab-server >= 1.0.0
Requires:       nodejs >= 10
Requires:       npm >= 10
Requires:       python3-jupyterlab = %{version}
Provides:       jupyter-jupyterlab-discovery = 6
Obsoletes:      jupyter-jupyterlab-discovery < 6

%description -n jupyter-%{pypi_name}
An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

JupyterLab is the next-generation user interface for Project Jupyter
offering all the familiar building blocks of the classic Jupyter
Notebook (notebook, terminal, text editor, file browser, rich outputs,
etc.).

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%generate_buildrequires
%pyproject_buildrequires %{?with_check:-x test}

%build
%pyproject_wheel

%install
export DONT_CLEANUP=true
%pyproject_install
%pyproject_save_files jupyterlab

%{jupyter_move_config}

chmod a+x %{buildroot}%{python3_sitelib}/jupyterlab/node-version-check.js
chmod a+x %{buildroot}%{python3_sitelib}/jupyterlab/staging/yarn.js

%if %{with check}
%check
export PYTHONDONTWRITEBYTECODE=1
# Disable build checks that pull in remote resources with npm
pytest %{buildroot}%{python3_sitelib}/jupyterlab/ -k \
    'not (test_build or test_clear or test_build_check or test_build_custom or test_uninstall_core_extension or test_install_and_uninstall_pinned or test_install_and_uninstall_pinned_folder or test_install_extension or test_load_extension)'
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE

%files -n jupyter-%{pypi_name}
%license LICENSE
%{_bindir}/jlpm
%{_bindir}/jupyter-lab
%{_bindir}/jupyter-labhub
%{_bindir}/jupyter-labextension
%config %{_sysconfdir}/jupyter/jupyter_notebook_config.d/jupyterlab.json
%config %{_sysconfdir}/jupyter/jupyter_server_config.d/jupyterlab.json
%{_jupyter_lab_dir}
%{_datadir}/applications/jupyterlab.desktop
%{_iconsdir}/hicolor/scalable/apps/jupyterlab.svg


%changelog
* Sun Mar 02 2025 wally <wally> 4.3.4-2.mga10
+ Revision: 2157816
- rebuild for python3.13

* Thu Jan 02 2025 papoteur <papoteur> 4.3.4-1.mga10
+ Revision: 2134929
- new version 4.3.4

* Tue Dec 26 2023 wally <wally> 4.0.9-1.mga10
+ Revision: 2021936
- new version 4.0.9

* Sun Jan 15 2023 wally <wally> 3.5.2-1.mga9
+ Revision: 1933378
- new version 3.5.2

* Thu Nov 03 2022 papoteur <papoteur> 3.0.17-2.mga9
+ Revision: 1902044
- rebuild for fastjsonschema dependency

* Mon Sep 05 2022 bcornec <bcornec> 3.0.17-1.mga9
+ Revision: 1884305
- Update to upstream python-jupyterlab 3.0.17 to fix mga#30699

* Sun Apr 03 2022 umeabot <umeabot> 3.0.12-3.mga9
+ Revision: 1841798
- Mageia 9 Mass Rebuild

* Sun Mar 06 2022 mrambo3501 <mrambo3501> 3.0.12-2.mga9
+ Revision: 1789151
- rebuild for python-3.10

* Wed Apr 07 2021 joequant <joequant> 3.0.12-1.mga9
+ Revision: 1714008
- fix deps
- add sniffio
- add jupyter-server
- add buildrequires
- update to 3.0.12

* Wed May 20 2020 joequant <joequant> 2.1.2-5.mga8
+ Revision: 1586467
- remove tornado requires

* Wed May 20 2020 joequant <joequant> 2.1.2-4.mga8
+ Revision: 1586446
- fix up autorequires

* Wed May 20 2020 joequant <joequant> 2.1.2-3.mga8
+ Revision: 1586294
- fix version of pyproject

* Tue May 19 2020 joequant <joequant> 2.1.2-2.mga8
+ Revision: 1586162
- redo deps

* Tue May 19 2020 joequant <joequant> 2.1.2-1.mga8
+ Revision: 1586130
- add pyproject-rpm-macros
- imported package python-jupyterlab

